@@ -60,6 +60,8 @@ DefaultAction.prototype.beginEvent = function() {
     this.setState(DefaultAction.State.Neutral);
     this.blockRefId = RObject.INVALID_ID;
     this.entityInBlockId = RObject.INVALID_ID;
+
+    this.optOutRelativeZeroResume = true;
 };
 
 DefaultAction.prototype.setState = function(state) {
@@ -133,6 +135,8 @@ DefaultAction.prototype.suspendEvent = function() {
     if (!isNull(this.getGuiAction())) {
         this.getGuiAction().setChecked(false);
     }
+
+    EAction.prototype.suspendEvent.call(this);
 };
 
 DefaultAction.prototype.resumeEvent = function() {
@@ -169,13 +173,18 @@ DefaultAction.prototype.mouseMoveEvent = function(event) {
         if (referencePoint.isValid()) {
             this.highlightReferencePoint(referencePoint);
         } else {
-            range = view.mapDistanceFromView(this.pickRangePixels);
-            var strictRange = view.mapDistanceFromView(10);
-            RMouseEvent.setOriginalMousePos(event.globalPos());
-            entityId = this.di.getClosestEntity(event.getModelPosition(), range, strictRange, false);
-            RMouseEvent.resetOriginalMousePos();
-            if (entityId !== RObject.INVALID_ID && this.document.isEntityEditable(entityId)) {
-                this.highlightEntity(entityId);
+            if (RSettings.getBoolValue("GraphicsView/HighlightEntity", true)===true) {
+
+                entityId = EAction.getEntityIdUnderCursor(this.getDocumentInterface(), event, undefined, true);
+
+//                range = view.mapDistanceFromView(this.pickRangePixels);
+//                var strictRange = view.mapDistanceFromView(10);
+//                RMouseEvent.setOriginalMousePos(event.globalPos());
+//                entityId = this.di.getClosestEntity(event.getModelPosition(), range, strictRange, false);
+//                RMouseEvent.resetOriginalMousePos();
+                if (entityId !== RObject.INVALID_ID && this.document.isEntityEditable(entityId)) {
+                    this.highlightEntity(entityId);
+                }
             }
         }
         break;
@@ -320,9 +329,10 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
             entityId = this.getEntityId(event, false, true);
 
             //qDebug("entityId: ", entityId);
+            //if (entityId!==RObject.INVALID_ID) qDebug("  parentId: ", this.document.queryEntityDirect(entityId).getParentId());
 
             if (entityId !== -1) {
-                if (addToSelection && this.document.isSelected(entityId)) {
+                if (addToSelection && (this.document.isSelected(entityId) || this.document.isSelectedWorkingSet(entityId))) {
                     this.deselectEntity(entityId);
                 }
                 else {
@@ -434,15 +444,17 @@ DefaultAction.prototype.mousePressEvent = function(event) {
 };
 
 DefaultAction.prototype.mouseDoubleClickEvent = function(event) {
-    if (event.button() == Qt.LeftButton && this.state===DefaultAction.State.Neutral) {
+    if (event.button() == Qt.LeftButton && (this.state===DefaultAction.State.Neutral || this.state===DefaultAction.State.Dragging)) {
+        if (this.state===DefaultAction.State.Dragging) {
+            // cancel dragging (double-click):
+            this.setState(DefaultAction.State.Neutral);
+        }
         var view = event.getGraphicsView();
         var range = view.mapDistanceFromView(this.pickRangePixels);
         var strictRange = view.mapDistanceFromView(10);
         var entityId = this.di.getClosestEntity(event.getModelPosition(), range, strictRange, false);
         if (entityId===RObject.INVALID_ID) {
-            if (this.document.getCurrentViewportId()!==RObject.INVALID_ID) {
-                this.di.unsetCurrentViewport();
-            }
+            this.emptySpaceDoubleClicked();
             return;
         }
 
@@ -451,6 +463,12 @@ DefaultAction.prototype.mouseDoubleClickEvent = function(event) {
     EAction.prototype.mouseDoubleClickEvent.call(this, event);
 };
 
+DefaultAction.prototype.emptySpaceDoubleClicked = function() {
+    if (this.document.getCurrentViewportId()!==RObject.INVALID_ID) {
+        this.di.unsetCurrentViewport();
+    }
+};
+
 DefaultAction.prototype.escapeEvent = function(event) {
     this.di.clearPreview();
     this.di.repaintViews();
@@ -458,6 +476,11 @@ DefaultAction.prototype.escapeEvent = function(event) {
     this.setState(DefaultAction.State.Neutral);
 };
 
+DefaultAction.prototype.coordinateEvent = function(event) {
+    // required to make sure invalid coordinate event goes through (needed for drag and drop):
+    this.pickCoordinate(event, false);
+};
+
 DefaultAction.prototype.pickCoordinate = function(event, preview) {
     var op;
 
@@ -699,7 +722,13 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
 
         if (RSettings.getBoolValue("GraphicsView/DoubleClickSelectContour", true)===true) {
             include("scripts/Select/SelectContour/SelectContour.js");
-            var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, 0.001);
+            var tol = RSettings.getDoubleValue("GraphicsView/DoubleClickSelectContourTolerance", 0.001);
+            var layerId = RObject.INVALID_ID;
+            if (isAltPressed(event)) {
+                // Alt: restrict to same layer:
+                layerId = entity.getLayerId();
+            }
+            var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, tol, layerId);
             var add = isShiftPressed(event);
             if (entity.isSelected()) {
                 this.di.selectEntities(matchingEntityIds, add);
