@@ -393,7 +393,7 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
         if (optionsToolBar.floating) {
             optionsToolBar.resize(optionsToolBar.sizeHint.width(), optionsToolBar.height);
         }
-        wOptions.destroy();
+        destr(wOptions);
 
         // automatically add separator to toolbar:
         var a = optionsToolBar.addSeparator();
@@ -498,7 +498,7 @@ EAction.prototype.hideUiOptions = function(saveToSettings) {
         if (!isNull(optionsToolBar)) {
             optionsToolBar.removeAction(a);
         }
-        a.destroy();
+        destr(a);
     }
 
     // delete additional toolbars of this tool if available:
@@ -508,7 +508,7 @@ EAction.prototype.hideUiOptions = function(saveToSettings) {
             if (isDeleted(tb)) {
                 continue;
             }
-            tb.destroy();
+            destr(tb);
         }
     }
 
@@ -545,7 +545,7 @@ EAction.prototype.hideOptionsToolBarWidgets = function(widgets, noSyncWidgets) {
     for (i = 0; i < children.length; ++i) {
         c = children[i];
         if (c["HideInDialogMode"]===true) {
-            c.destroy();
+            destr(c);
         }
         else if (c["MoveToDialog"]===true) {
             widgets.push(c);
@@ -665,7 +665,7 @@ EAction.prototype.showDialog = function() {
         noSyncWidgets[i].setProperty("Loaded", false);
     }
 
-    this.dialog.destroy();
+    destr(this.dialog);
     this.dialog = undefined;
 
 //    var view = EAction.getGraphicsView();
@@ -979,7 +979,7 @@ EAction.getMenu = function(title, objectName, initFunction) {
     var appWin = EAction.getMainWindow();
     var menuBar = appWin.menuBar();
     var menu;
-    for ( var i in menuBar.children()) {
+    for (var i in menuBar.children()) {
         menu = menuBar.children()[i];
         if (menu.objectName === objectName) {
             break;
@@ -1097,7 +1097,9 @@ EAction.getToolBar = function(title, objectName, toolBarArea, category, before)
     }
 
     if (!isNull(tb) && !isOfType(tb, QToolBar)) {
-        qWarning("Not a toolbar: ", tb);
+        qWarning("Not a toolbar: " + tb);
+        qWarning("tb type: " + tb.getType());
+        qWarning("QToolBar type: " + QToolBar.getType());
         return undefined;
     }
 
@@ -1152,7 +1154,7 @@ EAction.getOptionsToolBar = function() {
     }
 
     if (!isNull(EAction.optionsToolBar)) {
-        if (!QCoreApplication.arguments().contains("-no-show")) {
+        if (!RSettings.getOriginalArguments().contains("-no-show")) {
             EAction.optionsToolBar.visible = true;
         }
     }
@@ -1395,8 +1397,6 @@ EAction.addGuiActionTo = function(action, iface, addToMenu, addToToolBar,
         qWarning("EAction.js:", "addGuiActionTo(): iface not defined");
     }
 
-
-
     if (action.icon.isNull() && !action.isIconDisabled()) {
         action.setIcon(autoPath("scripts/Empty.svg"));
     }
@@ -1752,7 +1752,8 @@ EAction.prototype.applyOperation = function() {
         return false;
     }
     this.complementOperation(op);
-    di.applyOperation(op);
+    var t = di.applyOperation(op);
+    this.postOperation(t);
     return true;
 };
 
@@ -1763,6 +1764,13 @@ EAction.prototype.complementOperation = function(op) {
     return;
 };
 
+/**
+ * Can be reimplemented to work with the transaction returned by the operation.
+ */
+EAction.prototype.postOperation = function(transaction) {
+    return;
+};
+
 /**
  * High level event triggered when a coordinate was specified by the user of a
  * coordinate specification should be previewed.
