@@ -76,10 +76,14 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
     if (!new QFileInfo(uiFile).isAbsolute()) {
         candidates = [
             uiFile,
-            basePath + "/" + uiFile,
-            ":" + uiFile,
-            ":" + basePath + "/" + uiFile
+            basePath + "/" + uiFile
         ];
+        if (!uiFile.startsWith(":")) {
+            candidates.push(":" + uiFile);
+        }
+        if (!basePath.startsWith(":")) {
+            candidates.push(":" + basePath + "/" + uiFile);
+        }
     }
     else {
         candidates = [
@@ -114,7 +118,7 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
 
     var formWidget = loader.load(buf, parent);
     buf.close();
-    loader.destroy();
+    destr(loader);
 
     if (isNull(formWidget)) {
         qDebug("WidgetFactory.createWidget: widget is NULL");
@@ -137,7 +141,7 @@ WidgetFactory.createDialog = function(basePath, uiFile, parent) {
     var dialog = WidgetFactory.createWidget(basePath, uiFile, parent);
 
     var flags = dialog.windowFlags();
-    flags = new Qt.WindowFlags(flags & ~(Qt.WindowContextHelpButtonHint));
+    flags = makeQtWindowFlags(flags & ~(Qt.WindowContextHelpButtonHint));
     dialog.setWindowFlags(flags);
 
     // a global function might be defined to do additional
@@ -373,7 +377,7 @@ WidgetFactory.saveState = function(widget, group, document, map) {
             }
         }
         else if (c.toString().startsWith("RFontChooserWidget")) {
-            value = c.getFont();
+            value = c.getChosenFont();
         }
 
         if (isNull(value)) {
@@ -486,8 +490,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
 
         // skip children from other groups in this widget (for options toolbar):
         // but not if used from a test [map != undefined]
-        if (isNull(map) && typeof (c["SettingsGroup"]) != "undefined"
-                && c["SettingsGroup"] !== group) {
+        if (isNull(map) && typeof (c["SettingsGroup"]) != "undefined" && c["SettingsGroup"] !== group) {
             continue;
         }
 
@@ -510,9 +513,8 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         
         var key = WidgetFactory.getKeyString(group, c);
         var value;
-        if (reset && !isNull(c.defaultValue) && (typeof(c["SettingsGroup"])=="undefined" ||
-                c["SettingsGroup"]===group)) {
-            value = c.defaultValue;
+        if (reset && !isNull(c.property("defaultValue")) && (typeof(c["SettingsGroup"])=="undefined" || c["SettingsGroup"]===group)) {
+            value = c.property("defaultValue");
         } else {
             if (!isNull(map)) {
                 value = map.get(key);                
@@ -564,21 +566,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
 //        qDebug("restoring: ", c.objectName);
 //        qDebug("  value: ", value);
 
-        if (isOfType(c, QLineEdit)) {
-            WidgetFactory.connect(c.textChanged, signalReceiver, c.objectName);
-            c.textChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.setProperty("defaultValue", c.text);
-            }
-            if (!isNull(value)) {
-                c.text = value;
-            }
-            continue;
-        }
         if (isOfType(c, QPlainTextEdit)) {
-            WidgetFactory.connect(c.textChanged, signalReceiver, c.objectName);
-            c.textChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
+            if (!reset) {
+                WidgetFactory.connect(c.textChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.textChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
                 c.setProperty("defaultValue", c.toPlainText());
             }
             if (!isNull(value)) {
@@ -587,11 +580,13 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RMathLineEdit)) {
-            WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
-            c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
+            if (!reset) {
+                WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.valueChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
                 //c.defaultValue = [c.text, c.getDefaultUnit()];
-                c.defaultValue = c.text;
+                c.setProperty("defaultValue", c.text);
                 c.slotTextChanged(c.text);
             }
             if (!isNull(value)) {
@@ -611,11 +606,13 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RMathComboBox)) {
-            WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
-            c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
+            if (!reset) {
+                WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.valueChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
                 //c.defaultValue = [c.text, c.getDefaultUnit()];
-                c.defaultValue = c.currentText;
+                c.setProperty("defaultValue", c.currentText);
                 c.slotTextChanged(c.currentText);
             }
             if (!isNull(value)) {
@@ -628,33 +625,55 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             continue;
         }
+        if (isOfType(c, QLineEdit)) {
+            if (!reset) {
+                WidgetFactory.connect(c.textChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.textChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.text);
+            }
+            if (!isNull(value)) {
+                c.text = value;
+            }
+            continue;
+        }
         if (isOfType(c, QToolButton) || isOfType(c, QPushButton)) {
 
-            if (!c.group() && !c.autoExclusive) {
+            if (isNull(c.group()) && !c.autoExclusive) {
                 if (c.checkable) {
-                    WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
-                    c.toggled.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-                    if (isNull(c.defaultValue)) {
-                        c.defaultValue = c.checked;
+                    if (!reset) {
+                        WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
+                        WidgetFactory.connect(c.toggled, WidgetFactory.topLevelWidget, "Setting");
+                    }
+                    if (isNull(c.property("defaultValue"))) {
+                        c.setProperty("defaultValue", c.checked);
                     }
                     if (!isNull(value)) {
                         c.checked = (value === true || value === "true");
                     }
                 }
                 else {
-                    WidgetFactory.connect(c.clicked, signalReceiver, c.objectName, false);
+                    if (!reset) {
+                        WidgetFactory.connect(c.clicked, signalReceiver, c.objectName, false);
+                    }
                 }
             }
             else {
-                WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
+                if (!reset) {
+                    WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
+                }
             }
             continue;
         }
         if (isOfType(c, QCheckBox)) {
-            WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
-            c.stateChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.checked;
+            if (!reset) {
+                WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.stateChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.checked);
                 if (!isNull(signalReceiver)) {
                     f = signalReceiver["slot"+c.objectName+"Changed"];
                     if (isFunction(f)) {
@@ -670,9 +689,9 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         if (isOfType(c, QRadioButton)) {
             if (!c.group() && !c.autoExclusive) {
                 WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
-                c.toggled.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-                if (isNull(c.defaultValue)) {
-                    c.defaultValue = c.checked;
+                WidgetFactory.connect(c.toggled, WidgetFactory.topLevelWidget, "Setting");
+                if (isNull(c.property("defaultValue"))) {
+                    c.setProperty("defaultValue", c.checked);
                 }
                 if (!isNull(value)) {
                     c.checked = (value === true || value == "true");
@@ -680,7 +699,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             else {
                 WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
-                c.toggled.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+                WidgetFactory.connect(c.toggled, WidgetFactory.topLevelWidget, "Setting");
                 if (value==="true") {
                     c.checked = value;
                 }
@@ -691,11 +710,14 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, QButtonGroup)) {
-            WidgetFactory.connect(c["buttonClicked(QAbstractButton*)"], signalReceiver, c.objectName);
-            if (isNull(c.defaultValue)) {
+            if (!reset) {
+                WidgetFactory.connect(c["buttonClicked(QAbstractButton*)"], signalReceiver, c.objectName);
+                WidgetFactory.connect(c["buttonClicked(QAbstractButton*)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
                 var button = c.checkedButton();
                 if (button) {
-                    c.defaultValue = button.objectName;
+                    c.setProperty("defaultValue", button.objectName);
                     if (!isNull(signalReceiver)) {
                         f = signalReceiver["slot"+c.objectName+"Changed"];
                         if (isFunction(f)) {
@@ -721,10 +743,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
         }
         if (isOfType(c, QComboBox) && c.editable) {
-            WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
-            c.editTextChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.currentText;
+            if (!reset) {
+                WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c.editTextChanged, WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.currentText);
                 if (!isNull(signalReceiver)) {
                     f = signalReceiver["slot" + c.objectName + "Changed"];
                     if (isFunction(f)) {
@@ -743,17 +767,19 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if ((isOfType(c, QComboBox) && !c.editable) || isOfType(c, QFontComboBox)) {
-            WidgetFactory.connect(c['currentIndexChanged(int)'], signalReceiver, c.objectName);
-            c["currentIndexChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+            if (!reset) {
+                WidgetFactory.connect(c['currentIndexChanged(int)'], signalReceiver, c.objectName);
+                WidgetFactory.connect(c['currentIndexChanged(int)'], WidgetFactory.topLevelWidget, "Setting");
+            }
             hasData = false;
             if (c.itemData(c.currentIndex)!=undefined) {
                 hasData = true;
             }
-            if (isNull(c.defaultValue)) {
+            if (isNull(c.property("defaultValue"))) {
                 if (hasData) {
-                    c.defaultValue = c.itemData(c.currentIndex);
+                    c.setProperty("defaultValue", c.itemData(c.currentIndex));
                 } else {
-                    c.defaultValue = c.currentText;
+                    c.setProperty("defaultValue", c.currentText);
                 }
                 if (signalReceiver!=undefined) {
                     f = signalReceiver["slot" + c.objectName + "Changed"];
@@ -789,10 +815,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RColorCombo)) {
-            WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
-            c["currentIndexChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.getColor();
+            if (!reset) {
+                WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c["currentIndexChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.getColor());
             }
             if (!isNull(value)) {
                 // color name given:
@@ -813,10 +841,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RLineweightCombo)) {
-            WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
-            c["currentIndexChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.getLineweight();
+            if (!reset) {
+                WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c["currentIndexChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.getLineweight());
             }
             if (!isNull(value)) {
                 if (isString(value)) {
@@ -827,10 +857,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, RLinetypeCombo)) {
-            WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
-            c["currentIndexChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.getLinetypePattern();
+            if (!reset) {
+                WidgetFactory.connect(c.editTextChanged, signalReceiver, c.objectName);
+                WidgetFactory.connect(c["currentIndexChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.getLinetypePattern());
             }
             if (!isNull(value)) {
                 c.setLinetypePattern(value);
@@ -838,17 +870,18 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, QSpinBox) || isOfType(c, QDoubleSpinBox)) {
-            if (isOfType(c, QSpinBox)) {
-                WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
-                c["valueChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+            if (!reset) {
+                if (isOfType(c, QSpinBox)) {
+                    WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
+                    WidgetFactory.connect(c["valueChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+                }
+                else {
+                    WidgetFactory.connect(c["valueChanged(double)"], signalReceiver, c.objectName);
+                    WidgetFactory.connect(c["valueChanged(double)"], WidgetFactory.topLevelWidget, "Setting");
+                }
             }
-            else {
-                WidgetFactory.connect(c["valueChanged(double)"], signalReceiver, c.objectName);
-                c["valueChanged(double)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            }
-
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.value;
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.value);
                 if (signalReceiver!=undefined) {
                     f = signalReceiver["slot" + c.objectName + "Changed"];
                     if (isFunction(f)) {
@@ -862,11 +895,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             continue;
         }
         if (isOfType(c, QSlider)) {
-            WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
-            c["valueChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.value;
+            if (!reset) {
+                WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
+                WidgetFactory.connect(c["valueChanged(int)"], WidgetFactory.topLevelWidget, "Setting");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.value);
                 if (signalReceiver!=undefined) {
                     f = signalReceiver["slot" + c.objectName + "Changed"];
                     if (isFunction(f)) {
@@ -890,19 +924,19 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
 
             if (saveContents) {
-                if (isNull(c.defaultValue)) {
+                if (isNull(c.property("defaultValue"))) {
                     var items = [];
                     for (j = 0; j < c.count; ++j) {
                         items.push(c.item(j).text());
                     }
-                    c.defaultValue = items;
+                    c.setProperty("defaultValue", items);
                 }
                 if (!isNull(value)) {
                     c.addItems(value);
                 }
             } else {
-                if (isNull(c.defaultValue) && !isNull(c.currentItem())) {
-                    c.defaultValue = c.currentItem().data(Qt.UserRole);
+                if (isNull(c.property("defaultValue")) && !isNull(c.currentItem())) {
+                    c.setProperty("defaultValue", c.currentItem().data(Qt.UserRole));
                 }
                 if (!isNull(value)) {
                     for (j=0; j<c.count; ++j) {
@@ -947,17 +981,21 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 }
             }
 
-            WidgetFactory.connect(c.itemChanged, signalReceiver, c.objectName);
-            c.itemSelectionChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            c.model().rowsInserted.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");            
+            if (!reset) {
+                WidgetFactory.connect(c.itemChanged, signalReceiver, c.objectName);
+                c.itemSelectionChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+                c.model().rowsInserted.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+            }
             
             continue;
         }
         if (isOfType(c, RFontChooserWidget)) {
-            WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
-            c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-            if (isNull(c.defaultValue)) {
-                c.defaultValue = c.getFont();
+            if (!reset) {
+                WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
+                c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+            }
+            if (isNull(c.property("defaultValue"))) {
+                c.setProperty("defaultValue", c.getChosenFont());
             }
             if (!isNull(value)) {
                 if (isString(value)) {
@@ -1008,6 +1046,7 @@ WidgetFactory.connect = function(sig, signalReceiver, objectName, isValue) {
     }
 
     // connect signal to given function:
+    // obsolete?
     if (isFunction(signalReceiver)) {
         sig.connect(signalReceiver);
         return;
@@ -1024,7 +1063,12 @@ WidgetFactory.connect = function(sig, signalReceiver, objectName, isValue) {
 
     //if (eval("signalReceiver." + slot) != undefined) {
     if (!isNull(signalReceiver[slot])) {
-        sig.connect(signalReceiver, slot);
+        if (RSettings.getQtVersion() > 0x060000) {
+            sig.connect(signalReceiver, signalReceiver[slot]);
+        }
+        else {
+            sig.connect(signalReceiver, slot);
+        }
     }
 };
 
@@ -1203,7 +1247,7 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
                 symbolSelf = symbolCode;
             }
             var symbolText = symbol[1];
-            var insertion = symbol[0];
+            var insertion = String.fromCharCode(symbol[0]);
             if (symbol.length===3) {
                 insertion = symbol[2];
             }
@@ -1224,9 +1268,9 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
     });
 };
 
-WidgetFactory.initTextBrowser = function(textBrowser, linkHandler, slot) {
+WidgetFactory.initTextBrowser = function(textBrowser, slot) {
     textBrowser.openLinks = false;
-    textBrowser.anchorClicked.connect(linkHandler, slot);
+    textBrowser.anchorClicked.connect(slot);
 };
 
 //WidgetFactory.initWebView = function(webView, linkHandler, slot) {
@@ -1469,7 +1513,9 @@ WidgetFactory.installComboBoxEventFilter = function(widget) {
             isOfType(c, RLineweightCombo) ||
             isOfType(c, RLinetypeCombo)) {
 
-            c.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
+            if (isFunction(c.installEventFilter)) {
+                c.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
+            }
             c.focusPolicy = Qt.ClickFocus;
             continue;
         }
