@@ -62,21 +62,22 @@ function RBlockListQt(parent, addListener, showHeader) {
     this.setColumnWidth(BlockList.colVisible, 22);
     this.setColumnWidth(BlockList.colEdit, 22);
 
+    var self = this;
     if (addListener) {
         var appWin = EAction.getMainWindow();
         var adapter = new RBlockListenerAdapter();
         appWin.addBlockListener(adapter);
-        adapter.blocksUpdated.connect(this, "updateBlocks");
-        adapter.currentBlockSet.connect(this, "updateCurrentBlock");
-        adapter.blocksCleared.connect(this, "clearBlocks");
+        adapter.blocksUpdated.connect(function(di) { self.updateBlocks(di); });
+        adapter.currentBlockSet.connect(function(di) { self.updateCurrentBlock(di); });
+        adapter.blocksCleared.connect(function() { self.clearBlocks(); });
     }
 
-    this.itemDoubleClicked.connect(this, "editBlock");
-    this.itemColumnClicked.connect(this, "itemColumnClickedSlot");
-    this.itemSelectionChanged.connect(this, "blockActivated");
+    this.itemDoubleClicked.connect(function(item, col) { self.editBlock(item, col); });
+    this.itemColumnClicked.connect(function(item, col) { self.itemColumnClickedSlot(item, col); });
+    this.itemSelectionChanged.connect(function() { self.blockActivated(); });
     this.basePath = includeBasePath;
 
-    this.currentItem = undefined;
+    this.currentBlockItem = undefined;
 
 }
 
@@ -179,23 +180,23 @@ RBlockListQt.prototype.updateCurrentBlock = function(documentInterface) {
     var doc = documentInterface.getDocument();
 
     // find item which was representing the current block before:
-    if (!isNull(this.currentItem)) {
+    if (!isNull(this.currentBlockItem)) {
         // clear pen icon from item:
-        //var blockName = this.currentItem.data(BlockList.colName, Qt.UserRole);
+        //var blockName = this.currentBlockItem.data(BlockList.colName, Qt.UserRole);
         //var block = doc.queryBlock(blockName);
-        //this.updateItemIcons(this.currentItem, block);
-        this.currentItem.setIcon(BlockList.colEdit, BlockList.iconEdit[0]);
+        //this.updateItemIcons(this.currentBlockItem, block);
+        this.currentBlockItem.setIcon(BlockList.colEdit, BlockList.iconEdit[0]);
     }
 
     // find item of current block:
-    this.currentItem = RBlockListQt.getItem(this, doc.getCurrentBlockName());
+    this.currentBlockItem = RBlockListQt.getItem(this, doc.getCurrentBlockName());
     //for (var i=0; i<this.topLevelItemCount; i++) {
     //    var item = this.topLevelItem(i);
     //}
 
     // add pen icon to item:
-    if (!isNull(this.currentItem)) {
-        this.currentItem.setIcon(BlockList.colEdit, BlockList.iconEdit[1]);
+    if (!isNull(this.currentBlockItem)) {
+        this.currentBlockItem.setIcon(BlockList.colEdit, BlockList.iconEdit[1]);
     }
 };
 
@@ -203,7 +204,7 @@ RBlockListQt.prototype.updateCurrentBlock = function(documentInterface) {
  * Called when blocks are added, edited or deleted. Updates the block list.
  */
 RBlockListQt.prototype.updateBlocks = function(documentInterface) {
-    this.currentItem = undefined;
+    this.currentBlockItem = undefined;
 
     this.di = documentInterface;
 
@@ -261,7 +262,7 @@ RBlockListQt.prototype.updateBlocks = function(documentInterface) {
         }
 
         if (currentBlockId===block.getId()) {
-            this.currentItem = item;
+            this.currentBlockItem = item;
         }
     }
 
@@ -554,9 +555,14 @@ BlockList.init = function(basePath) {
 
     var formWidget = WidgetFactory.createWidget(basePath, "BlockList.ui");
     var layout = formWidget.findChild("verticalLayout");
-    var blockList = new RBlockListQt(layout);
+    var blockList = new RBlockListQt(formWidget);
     blockList.objectName = "BlockList";
-    layout.addWidget(blockList, 1, 0);
+    if (RSettings.getQtVersion()>0x060000) {
+        layout.addWidget(blockList);
+    }
+    else {
+        layout.addWidget(blockList, 1, 0);
+    }
 
     RSettings.setValue("BlockList/AlternatingRowColor", new RColor(230, 235, 250), false);
     WidgetFactory.initList(blockList, "BlockList");
